@@ -5,11 +5,11 @@
 
 #include <QObject>
 #include <QDebug>
-#ifdef Q_WS_MAEMO_5
+//#ifdef Q_WS_MAEMO_5
     #include <dbus-1.0/dbus/dbus.h>
     #include <libosso.h>
     #include <libplayback-1/libplayback/playback.h>
-#endif
+//#endif
 
 class OssoWrapper : public QObject
 {
