@@ -59,8 +59,8 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
 
-    m_pSpectrum = new SpectrumAnalyzer(this,50,40);
-    m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
+    //m_pSpectrum = new SpectrumAnalyzer(this,50,40);
+    //m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
     //init the trackinfo listview instance and associated item delegate
     m_pTrackInfoView = new QListView(this);
@@ -138,9 +138,9 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
     m_pPlayerControlsHoriz->addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
     m_pPlayerControlsHoriz->setColumnStretch(3,5);
     m_pPlayerControlsHoriz->addWidget(m_pProgressSlider,0,4,1,1);
-    m_pPlayerControlsHoriz->setColumnMinimumWidth(4,370);
+    m_pPlayerControlsHoriz->setColumnMinimumWidth(4,SLIDER_WIDTH_LANDSCAPE);
     m_pPlayerControlsHoriz->setColumnStretch(4,10);
-    m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
+    //m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
     m_pPlayerControlsHoriz->setContentsMargins(10,5,10,0);
 
     m_pHorizGridLayout = new QGridLayout();
@@ -360,13 +360,13 @@ void QueueView::OnPlayingState(bool state)
     if(state)
     { //playing state
         m_playing = true;
-        if(m_update)
-            m_pSpectrum->Start();
+        //if(m_update)
+            //m_pSpectrum->Start();
     }
     else
     { //paused state
         m_playing = false;
-        m_pSpectrum->Stop();
+       // m_pSpectrum->Stop();
     }
 }
 
@@ -545,12 +545,6 @@ void QueueView::playTrack(Spotify::Track* track)
     m_userInitiatedPause = false;
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
-#ifdef Q_WS_MAEMO_5
-    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
-    QMaemo5InformationBox::information(this,tr("Buffering"));
-#else
-    Banner::information(this,tr("Buffering"));
-#endif
 
     error = m_pSession->play(track); //request to start playback of track
     if(error.isError())
@@ -1105,7 +1099,7 @@ void QueueView::OnOrientationChanged()
         m_pPlayerControlsVert->removeWidget(&m_PauseResumeBtn);
         m_pPlayerControlsVert->removeWidget(&m_NextBtn);
         m_pPlayerControlsVert->removeWidget(&m_ShuffleBtn);
-        m_pPlayerControlsVert->removeWidget(m_pSpectrum);
+        //m_pPlayerControlsVert->removeWidget(m_pSpectrum);
         m_pProgressLayoutVert->removeWidget(m_pProgressSlider);
 
         m_pHorizGridLayout->addWidget(&m_AlbumCover,0,0,7,1,Qt::AlignTop);
@@ -1120,9 +1114,9 @@ void QueueView::OnOrientationChanged()
         m_pPlayerControlsHoriz->addWidget(m_pProgressSlider,0,4,1,1);
         m_currSliderWidth = SLIDER_WIDTH_LANDSCAPE;
         m_pProgressSlider->setSize(m_currSliderWidth,SLIDER_HEIGHT);
-        m_pPlayerControlsHoriz->setColumnMinimumWidth(4,370);
+        m_pPlayerControlsHoriz->setColumnMinimumWidth(4,SLIDER_WIDTH_LANDSCAPE);
         m_pPlayerControlsHoriz->setColumnStretch(4,10);
-        m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
+       // m_pPlayerControlsHoriz->addWidget(m_pSpectrum,0,5,1,1,Qt::AlignRight);
         m_MainLayout.setCurrentIndex(LANDSCAPE_ORIENTATION); //active landscape layout
     }
     else
@@ -1139,7 +1133,7 @@ void QueueView::OnOrientationChanged()
         m_pPlayerControlsHoriz->removeWidget(&m_NextBtn);
         m_pPlayerControlsHoriz->removeWidget(&m_ShuffleBtn);
         m_pPlayerControlsHoriz->removeWidget(m_pProgressSlider);
-        m_pPlayerControlsHoriz->removeWidget(m_pSpectrum);
+       // m_pPlayerControlsHoriz->removeWidget(m_pSpectrum);
 
         m_pVertLayout->addWidget(&m_AlbumCover,0,0,1,1,Qt::AlignCenter);
         m_pVertLayout->addWidget(m_pTrackInfoView,1,0,1,1);
@@ -1148,9 +1142,9 @@ void QueueView::OnOrientationChanged()
         m_pPlayerControlsVert->addWidget(&m_PauseResumeBtn,0,1,1,1,Qt::AlignLeft);
         m_pPlayerControlsVert->addWidget(&m_NextBtn,0,2,Qt::AlignLeft);
         m_pPlayerControlsVert->setColumnStretch(2,6);
-        m_pPlayerControlsVert->addWidget(&m_ShuffleBtn,0,3,1,1,Qt::AlignLeft);
-        m_pPlayerControlsVert->setColumnStretch(3,5);
-        m_pPlayerControlsVert->addWidget(m_pSpectrum,0,4,1,1,Qt::AlignRight);
+        m_pPlayerControlsVert->addWidget(&m_ShuffleBtn,0,4,1,1,Qt::AlignRight);
+        //m_pPlayerControlsVert->setColumnStretch(3,5);
+        //m_pPlayerControlsVert->addWidget(m_pSpectrum,0,4,1,1,Qt::AlignRight);
         m_currSliderWidth = SLIDER_WIDTH_PORTRAIT;
         m_pProgressSlider->setSize(m_currSliderWidth,SLIDER_HEIGHT);
         m_pProgressLayoutVert->addWidget(m_pProgressSlider,0,0,1,-1);
@@ -1172,8 +1166,8 @@ void QueueView::OnDisplayStateChanged(bool state)
         m_update = true; //allow UI updates
         if(m_pCurrTrack)
         {
-            if(m_playing)
-                m_pSpectrum->Start();
+            //if(m_playing)
+               // m_pSpectrum->Start();
             OnTrackBufferedAmountUpdated(m_pSession->getBufferingPos()); //force update of track buffering position
             OnPlaybackPositionUpdated(m_pSession->getPlaybackPos()); //force update of playback position
         }
@@ -1181,7 +1175,7 @@ void QueueView::OnDisplayStateChanged(bool state)
     else
     { //display off
         m_update = false; //no UI updates
-        m_pSpectrum->Stop();
+       // m_pSpectrum->Stop();
     }
 }
 
