@@ -31,7 +31,7 @@
 #include <qspotify_src/spotifysession.h>
 #include <qspotify_src/imagecontainer.h>
 #include "CustomSlider.h"
-#include "SpectrumAnalyzer.h"
+//#include "SpectrumAnalyzer.h"
 #include "ListViewDelegate.h"
 #include "OssoWrapper.h"
 #include "DBusWrapper.h"
@@ -39,7 +39,7 @@
 
 //defines
 
-#define SLIDER_WIDTH_LANDSCAPE 355 //width of the custom progress slider widget (landscape mode)
+#define SLIDER_WIDTH_LANDSCAPE 405 //width of the custom progress slider widget (landscape mode)
 #define SLIDER_HEIGHT 40 //height of the custom progress slider widget
 #define SLIDER_WIDTH_PORTRAIT 440 //width of the custom progress slider widget (portrait mode)
 
@@ -114,7 +114,7 @@ private:
 
     qint32 m_currSliderWidth; //current slider width (for i.e., current portrait and landscape mode)
 
-    SpectrumAnalyzer* m_pSpectrum; //spectrum (active during audio playback)
+    //SpectrumAnalyzer* m_pSpectrum; //spectrum (active during audio playback)
 
     QListView* m_pTrackInfoView; //track info listview
 
