@@ -6,6 +6,7 @@
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QDialog>
+#include <QFileDialog>
 #include <QDebug>
 #include <QSettings>
 #include <QGroupBox>
@@ -41,8 +42,11 @@
 #define ENABLE_SCROBBLING_DEFAULT           0
 #define ORIENTATION_DEFAULT                 0
 #define PAUSE_ON_HEADSET_UNPLUG_DEFAULT     0
-#define LANG_DEFAULT                        "en"
+#define LANG_DEFAULT                        QString("en")
 #define ALLOW_MOBILE_SYNC_DEFAULT           1
+#define CACHE_PATH_EMMC                     QString("/home/user/MyDocs")
+#define CACHE_PATH_MMC                      QString("/media/mmc1")
+#define CACHE_DIR_NAME_DEFAULT              QString(".qspot")
 
 
 class SettingsDialog : public QDialog
@@ -70,17 +74,11 @@ private:
     QGridLayout m_GridLayout; //elements contained within the main scrollarea
 
     QGroupBox m_SearchOptions; //container for search related settings
-
     QGridLayout m_SearchOptionLayout;
 
     QGroupBox m_BufferingOptions; //container for settings related to buffering
-
     QGridLayout m_BufferingOptionLayout;
 
-    QGroupBox m_LoginOptions; //container for login-related settings
-
-    QGridLayout m_LoginOptionLayout;
-
     QCheckBox m_HideCoverArt; //checkbox to indicate whether the coverart should be hidden in the Queue View (to free more space for track info).
 
     QStringList m_bitrateList; //list of available bitrate alternatives
@@ -88,11 +86,8 @@ private:
 #ifdef Q_WS_MAEMO_5
 
     QMaemo5ValueButton m_PreferredBitrateBtn; //value type button for selecting the preferred bitrate
-
     QMaemo5ListPickSelector *m_pPreferredBitrateSelector; //pick selector associated with preferred bitrate value button
-
     QMaemo5ValueButton m_PreferredSyncBitrateBtn; //value type button for selecting the preferred offline sync. bitrate
-
     QMaemo5ListPickSelector *m_pPreferredSyncBitrateSelector; //pick selector associated with preferred offline sync. bitrate value button
 
 #else
@@ -106,9 +101,20 @@ private:
     QCheckBox m_AllowMobileSyncSelection; //checkbox for selecting whether sync. over mobile (3G) should be allowed or not
 
     QGroupBox m_ScrobblingOptions; //container for settings related to Last.fm scrobbling
-
     QGridLayout m_ScrobblingOptionLayout;
 
+    QGroupBox m_AdvancedOptions; //container for advanced settings
+    QGridLayout m_AdvancedOptionLayout;
+
+#ifdef Q_WS_MAEMO_5
+
+    QMaemo5ValueButton m_PathSelBtn; //value type button for selecting the settings / cache location (i.e., EMMC / MMC)
+    QMaemo5ListPickSelector *m_pPathSelector; //pick selector associated with the settings / cache location button
+
+#endif
+
+    QStringList m_pathLocationList; //list of possible settings / cache locations
+
     QLabel m_maxSearchTracksCaption;
     QLineEdit m_maxSearchTracksInput; //max. tracks returned by search
 
@@ -166,7 +172,6 @@ private:
     QPushButton m_SaveSettingsBtn; //Save current settings button
 
     //members holding current settings
-
     qint32 m_maxSearchTracks;
     qint32 m_maxSearchAlbums;
     qint32 m_maxSearchArtists;
@@ -182,6 +187,9 @@ private:
     qint32 m_currUILang;
     QString m_strLastFMUserID;
     QString m_strLastFMPassword;
+    QString m_strCacheDirPath;
+
+    bool mmcPresent(); //Returns true in case memory (SD) card is present; otherwiser returns false.
 
     void saveSettings(); //save (modified) settings
 
@@ -193,6 +201,7 @@ private slots:
     void OnSaveSettingsBtn();
     void OnScrobblingStateChanged(int newState);
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
+    void OnPathSelectionBtn(); //user has clicked the cache / setting path selection button
 
 signals:
 
