@@ -106,8 +106,9 @@ void LastFMScrobbler::OnRequestFinished(QNetworkReply *reply)
         {//reply to scrobble tracks request received
             for(qint32 pos = 0; pos < m_scrobblesInBatch; pos++) //clear the current scrobbles batch (sent to Last.fm successufully)
             {
-                m_ScrobblesList.removeAt(pos);
+                m_ScrobblesList.removeFirst();
             }
+            qDebug() << "Cleared scrobbles list after successful scrobble operation; count: " << m_ScrobblesList.size() << ", scrobbles in batch: " << m_scrobblesInBatch;
             cacheScrobbles(); //update cache status
             emit scrobbleTracksStatus(true,"");
         }
@@ -128,6 +129,7 @@ void LastFMScrobbler::OnRequestFinished(QNetworkReply *reply)
             }
             else
             {
+                m_strSessionKey = "";
                 emit authenticateSessionStatus(false,strErrorDesc);
             }
         }
@@ -251,6 +253,14 @@ QNetworkReply* LastFMScrobbler::postRequest( QMap<QString, QString> paramMap)
     return(m_pNetworkManager->post(req,requestData)); //post the request, and return pointer to reply instance
 }
 
+
+void LastFMScrobbler::invalidateSession()
+{
+    m_strSessionKey = "";
+    m_strUserID = "";
+    m_strUserPwd = "";
+}
+
 void LastFMScrobbler::authenticateSession(const QString& strUserID, const QString& strPassword)
 {
     //request a new session using the supplied Last.FM user credentials.
@@ -258,6 +268,13 @@ void LastFMScrobbler::authenticateSession(const QString& strUserID, const QStrin
     QByteArray authToken;
     QMap<QString, QString> params;
 
+    if(isSessionValid()) //no authentication required, valid session available
+    { //send of cached scrobbles in case online mode active
+        if(!m_bOfflineMode)
+            sendScrobbles();
+        return;
+    }
+
     m_strUserID = strUserID;
     m_strUserPwd = strPassword;
 
@@ -340,21 +357,24 @@ void LastFMScrobbler::sendScrobbles()
     else
         m_scrobblesInBatch = m_ScrobblesList.size();
 
-    for(qint32 pos = 0; pos < m_scrobblesInBatch; pos++)
+    if(m_scrobblesInBatch>0) //we have som scrobbles to send off
     {
-        track = m_ScrobblesList.at(pos);
-        params.insert("artist["+QString::number(pos)+ "]",track.m_strArtistName);
-        params.insert("track["+QString::number(pos)+ "]",track.m_strTrackName);
-        params.insert("album["+QString::number(pos)+ "]",track.m_strAlbumName);
-        if(track.m_strAlbumArtist!="")
-            params.insert("albumArtist["+QString::number(pos)+ "]",track.m_strAlbumArtist);
-        params.insert("timestamp["+QString::number(pos) + "]",QString::number(track.m_timestamp.toUTC().toTime_t())); //timestamp should be in unix-timestamp format (UTC)
+        for(qint32 pos = 0; pos < m_scrobblesInBatch; pos++)
+        {
+            track = m_ScrobblesList.at(pos);
+            params.insert("artist["+QString::number(pos)+ "]",track.m_strArtistName);
+            params.insert("track["+QString::number(pos)+ "]",track.m_strTrackName);
+            params.insert("album["+QString::number(pos)+ "]",track.m_strAlbumName);
+            if(track.m_strAlbumArtist!="")
+                params.insert("albumArtist["+QString::number(pos)+ "]",track.m_strAlbumArtist);
+            params.insert("timestamp["+QString::number(pos) + "]",QString::number(track.m_timestamp.toUTC().toTime_t())); //timestamp should be in unix-timestamp format (UTC)
+        }
+
+        params.insert("sk",m_strSessionKey);
+        params.insert("api_key",m_strAPIKey);
+
+        m_pScrobbleTracksReply = postRequest(params); //send of scrobble request
     }
-
-    params.insert("sk",m_strSessionKey);
-    params.insert("api_key",m_strAPIKey);
-
-    m_pScrobbleTracksReply = postRequest(params); //send of scrobble request
 }
 
 void LastFMScrobbler::cacheScrobbles()
@@ -363,15 +383,19 @@ void LastFMScrobbler::cacheScrobbles()
 
     QFile cacheFile(m_strCachePath + SCROBBLES_CACHE_FILENAME); //file instance holding providing access to serialization data file
 
-    cacheFile.open(QIODevice::WriteOnly); //opens backup file for writing only (the file is created if it does not already exist)
+    if(cacheFile.open(QIODevice::WriteOnly))
+    { //opens backup file for writing only (the file is created if it does not already exist)
 
-    QDataStream outStream(&cacheFile); //output stream for data serialization (attach to backup file instance)
+        QDataStream outStream(&cacheFile); //output stream for data serialization (attach to backup file instance)
 
-    outStream.setVersion(QDataStream::Qt_4_6); //set stream version
+        outStream.setVersion(QDataStream::Qt_4_7); //set stream version
 
-    outStream << m_ScrobblesList; //serialize current scrobbles queue to disk
+        outStream << m_ScrobblesList; //serialize current scrobbles queue to disk
 
-    cacheFile.close(); //finally, close the backup file
+        cacheFile.close(); //finally, close the backup file
+    }
+    else
+        qDebug() << "Failed to open cache file for writing..";
 }
 
 void LastFMScrobbler::restoreScrobbles()
