@@ -25,8 +25,8 @@ MainWindow::MainWindow(QWidget *parent)
     m_playing = false;
     m_update = false;
 
-    m_pSpectrum = new SpectrumAnalyzer(this,55,40);
-    m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
+    //m_pSpectrum = new SpectrumAnalyzer(this,55,40);
+    //m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
     m_pSyncProgress = new QProgressBar(this); //allocate progressbar indicator (offline synchronisation status)
     m_pSyncProgress->setVisible(false);
@@ -146,7 +146,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(&m_NowPlayingIcon,SIGNAL(clicked()),SLOT(OnNowPlaying()));
     connect(&m_NowPlayingInfo,SIGNAL(clicked()), SLOT(OnNowPlaying()));
     connect(&m_NowPlayingPositionInfo,SIGNAL(clicked()), SLOT(OnNowPlaying()));
-    connect(m_pSpectrum,SIGNAL(clicked()),SLOT(OnNowPlaying()));
+    //connect(m_pSpectrum,SIGNAL(clicked()),SLOT(OnNowPlaying()));
     connect(&m_SearchBtn,SIGNAL(clicked()),SLOT(OnSearch()));
     connect(&m_SearchInput,SIGNAL(returnPressed()),SLOT(OnSearch()));
     connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
@@ -170,11 +170,11 @@ MainWindow::MainWindow(QWidget *parent)
     m_NowPlayingFont.setFamily(QApplication::font().family());
     m_NowPlayingFont.setPointSize(14);
     m_NowPlayingInfo.setFont(m_NowPlayingFont);
-    m_NowPlayingInfo.setFixedWidth(510);
+    m_NowPlayingInfo.setFixedWidth(565);
     m_NowPlayingInfo.setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
     m_NowPlayingInfo.setText("----"); //default (empty) value for now playing info
     m_NowPlayingPositionInfo.setFont(m_NowPlayingFont);
-    m_NowPlayingPositionInfo.setFixedWidth(132);
+    //m_NowPlayingPositionInfo.setFixedWidth(132);
     m_NowPlayingPositionInfo.setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
     m_GridLayout.addWidget(&m_SearchInput,0,0,1,3);
@@ -183,8 +183,8 @@ MainWindow::MainWindow(QWidget *parent)
     m_GridLayout.addWidget(m_pPlaylistView,2,0,1,-1);
     m_GridLayout.addWidget(&m_NowPlayingIcon,3,0);
     m_GridLayout.addWidget(&m_NowPlayingInfo,3,1,1,1,Qt::AlignLeft);
-    m_GridLayout.addWidget(&m_NowPlayingPositionInfo,3,2,1,1,Qt::AlignRight);
-    m_GridLayout.addWidget(m_pSpectrum,3,3);
+    m_GridLayout.addWidget(&m_NowPlayingPositionInfo,3,2,1,-1,Qt::AlignRight);
+   // m_GridLayout.addWidget(m_pSpectrum,3,3);
 
     m_MainLayout.setLayout(&m_GridLayout);
     setCentralWidget(&m_MainLayout);
@@ -420,12 +420,12 @@ void MainWindow::OnPlayingState(bool state)
     if(state)
     { //playing state
         m_playing = true;
-        if(m_update)
-            m_pSpectrum->Start();
+       // if(m_update)
+          //  m_pSpectrum->Start();
     }
     else
     { //paused state
-        m_pSpectrum->Stop();
+        //m_pSpectrum->Stop();
         m_playing = false;
     }
 }
@@ -864,7 +864,7 @@ void MainWindow::OnSearch()
 #else
             Banner::information(this,tr("Searching"));
 #endif
-            error = m_pSession->search(m_SearchInput.text(),0,maxTracks,0,maxAlbums,0,maxArtists,NULL);
+            error = m_pSession->search(m_SearchInput.text(),0,maxTracks,0,maxAlbums,0,maxArtists,false,NULL);
             if(error.isError())
             { //some error occured
 #ifdef Q_WS_MAEMO_5
@@ -996,14 +996,14 @@ void MainWindow::OnDisplayStateChanged(bool state)
     {
         m_update = true; //allow UI updates
         //enable spectrum analyzer etc.
-        if(m_playing)
-            m_pSpectrum->Start();
+        //if(m_playing)
+         //   m_pSpectrum->Start();
     }
     else
     {
         m_update = false; //no UI updates
         //disable spectrum analyzer etc.
-        m_pSpectrum->Stop();
+        //m_pSpectrum->Stop();
 #ifdef Q_WS_MAEMO_5
         m_currSysVolume = m_pDBusWrapper->getVolume(); //store the current system volume
 #endif
