@@ -38,7 +38,7 @@
 #include "QueueView.h"
 #include "artistview.h"
 #include "AboutDialog.h"
-#include "SpectrumAnalyzer.h"
+//#include "SpectrumAnalyzer.h"
 #include "customlabel.h"
 #include "OssoWrapper.h"
 #include "lastfmscrobbler.h"
@@ -49,7 +49,7 @@
 
 //defines
 
-#define APP_VERSION "1.1.1-2" //application version string
+#define APP_VERSION "1.2.0-1" //application version string
 
 //menu bar actions
 #define MENU_ACTION_SETTINGS        0
@@ -131,7 +131,7 @@ private:
 
     QString m_strNowPlayingInfo;
 
-    SpectrumAnalyzer* m_pSpectrum; //spectrum analyzer widget
+    //SpectrumAnalyzer* m_pSpectrum; //spectrum analyzer widget
 
     QList<Spotify::Playlist*> m_Playlists; //list holding pointers to playlist instances
 
