@@ -31,7 +31,7 @@ sp_playlistcontainer_callbacks pc_callbacks = {
     &Spotify::Session::playlistAddedCallback,
     &Spotify::Session::playlistRemovedCallback,
     NULL,
-    NULL
+    &Spotify::Session::playListContainerLoadedCallback
 };
 
 #endif // CALLBACKS_H
