@@ -234,20 +234,22 @@ namespace Spotify
 
     void Playlist::playlistStateChanged()
     { //Playlist state has changed
-        bool emitSignal = false;
         if(m_collaborative != sp_playlist_is_collaborative( m_playlist ))
         {
             m_collaborative = sp_playlist_is_collaborative( m_playlist );
-            emitSignal = true;
         }
         if(m_offlineStatus!=(ePlaylistOfflineStatus)sp_playlist_get_offline_status(m_session, m_playlist))
         {
             m_offlineStatus = (ePlaylistOfflineStatus)sp_playlist_get_offline_status(m_session, m_playlist);
-            emitSignal = true;
         }
+		
+		if(sp_playlist_is_loaded( m_playlist))
+		{
+		    load();
+			updateTracks();
+		}
 
-        if(emitSignal)
-            emit updated();
+         emit updated();
     }
 
     void Playlist::playlistUpdateInProgress( qint32 done )
