@@ -660,18 +660,19 @@ void Spotify::Session::pauseResumeBuffering()
 
 Spotify::Error Spotify::Session::search( const QString& query, const int trackOffset, const int trackCount,
                                          const int albumOffset, const int albumCount, const int artistOffset,
-                                         const int artistCount, void* userdata )
+                                         const int artistCount, bool suggestedSearch, void* userdata )
 {
     Spotify::Error error;
     //sp_search_type type;
 
-    //if(suggestedSearch)
-      //  type=SP_SEARCH_SUGGEST;
-    //else
-      //  type=SP_SEARCH_STANDARD;
+    /*if(suggestedSearch)
+        type=SP_SEARCH_SUGGEST;
+    else
+        type=SP_SEARCH_STANDARD;
+        */
 
     sp_search* search = sp_search_create( m_session, query.toUtf8().data(), trackOffset, trackCount,
-                                          albumOffset, albumCount, artistOffset, artistCount, &searchCompleteCallback, userdata );
+                                          albumOffset, albumCount, artistOffset, artistCount,&searchCompleteCallback, userdata );
 
     Spotify::Search* s = new Spotify::Search(m_session, search, this );
     m_searchHash.insert( search, s );
@@ -748,8 +749,6 @@ void Spotify::Session::updateMetadata()
 {
     qDebug() << "metadata updated..";
 
-    bool loadedFlag = true; //false in case some playlist not loaded
-
     if(!m_playlistcontainer)
         m_playlistcontainer = sp_session_playlistcontainer(m_session); //get playlist root container
 
@@ -775,13 +774,13 @@ void Spotify::Session::updateMetadata()
             Spotify::Playlist* playlist = m_playlistList.at(i);
             if( playlist )
             {
-                loadedFlag = playlist->load(); //metadata processed for playlist (
+                playlist->load(); //metadata processed for playlist (
                 playlist->updateTracks(); //try to load tracks
             }
         }
 
-        if(loadedFlag && !m_allPlaylistsLoaded)
-        {
+        if(!m_allPlaylistsLoaded)
+        {//notify playlist container loading completed
             m_allPlaylistsLoaded = true;
             emit playlistContainersReady(m_playlistList); //all playlists have been loaded; emit ready signal
         }
@@ -1032,7 +1031,6 @@ void Spotify::Session::playListContainerLoadedCallback(sp_playlistcontainer *pc,
 void Spotify::Session::playListContainerLoadedWrapper(sp_playlistcontainer *pc, void* userdata)
 {
    Q_UNUSED( userdata );
-   qDebug()<< "Playlist container loaded";
 
    emit rootListContainerLoaded(pc);
 }
@@ -1050,6 +1048,8 @@ void Spotify::Session::OnRootListContainerLoaded(sp_playlistcontainer* pc)
          Spotify::Playlist* playlist = new Spotify::Playlist(m_session, PLAYLIST_TYPE_USER, sp_playlistcontainer_playlist(pc, pos), this);
 		 m_playlistList.insert(pos, playlist); //insert container instance into list
 	 }
+     m_allPlaylistsLoaded = true;
+     emit playlistContainersReady(m_playlistList);
 
 }
 
