@@ -162,7 +162,7 @@ namespace Spotify
              */
             Spotify::Error search( const QString& query, const int trackOffset, const int trackCount,
                                    const int albumOffset,const int albumCount, const int artistOffset,
-                                   const int artistCount, void* userData );
+                                   const int artistCount, bool suggestedSearch ,void* userData );
 
 
             /**
